# UiPath Integration (Public Preview)

The UiPath Integration extension provides a task to support build and release pipelines for UiPath projects. You can use this task to:

- Create the project nuget package given the project sources from source control
- Deploy UiPath project nuget packages to the Orchestrator

# Pack

Starts from the project sources taken from source control. The result is a NuGet package ready to be shipped to Orchestrator. It provides control over the following:
### Versioning Method
By using the **Chose the versioning method** field you can decide whether the NuGet package version should be pseudo-randomly generated by the task or provide a specific one. Auto-generating the version works just as Studio does the versioning when publishing a package.
Specifying the package version provides the possibility of tracking more efficiently the built packages and their source versioning. For example, the Microsoft assembly pattern can be utilized to build the NuGet package version: *[Major].[Minor].[BuildNumber].[RevisionNumber]*.
As a best practice, these fields should be stored as variables.
### UiPath Studio Setup On Build Agent Machine
The pack functionality wraps around the UiRobot.exe -pack command, so UiPath Studio needs to be installed on the build agent.
The following scenarios exist: UiPath Studio is installed on the build agent or it is not.
In case we’re facing a build agent that doesn’t have UiPath installed, you can configure the task to do so by following one of these two options:
- Filling in the **UiPath Version** field. This version of UiPath Studio is downloaded from UiPath’s public links. Keep in mind that your agent needs to be able to access those links. It has to be equal or greater than 18.3.2 and it has to follow the [Major].[Minor].[Patch] format.
- Specifying the path to the MSI. This provides the versatility of choosing between an URL or a shared drive. In case your agent can’t access the UiPath public URLs, you can host the MSI installer within your environment and provide it via an URL or a shared drive location.

In some cases, UiPath Studio might be already installed on the build agent machine and you want to make sure that a certain version is utilized to do the packaging. To have control over these situations, you can use the **Uninstall options** feature. It provides the following options:
- **Never** - If any version of UiPath Studio is installed on the target machine, the Pack task skips this step and proceeds with packing your artifact. If Studio is not installed on the agent, the version specified in the **UiPath version** field is installed.
- **Any Version** -  If any version of UiPath Studio is present on the agent machine, it is uninstalled and the one specified in UiPath Version is put in place. If Studio is not installed on the agent machine, the version specified  in the **UiPath version** field is installed.

- **Different Version** - UiPath Studio is installed on the target machine only if there is a mismatch between the version specified in the UiPath Version field and what is already installed.

By default UiPath Studio is installed in the C:\Program Files (x86)\UiPath. This can be configured by modifying the ‘UiPath Studio installation folder’ field.

### Project JSON Path
Most of the times the project.json file is located in the root folder of the UiPath process. In the situations when it’s not there you have the possibility to mention it in the **Project json path** field.
### Output Folder
By default this is set to *$(build.artifactstagingdirectory)*. In case you want the NuGet package to be stored in another location this field can be configured as such.

# Deploy
After having the NuGet package (or packages) built they can be published to Orchestrator by utilizing the **Deploy** function. It retrieves all nuget packages from the specified location, **Package path**, and publishes them into Orchestrator using its API.
The API calls use Bearer authentication, and therefore you need to provide your Tenant, Username, and Password.
Besides user/password, AD authentication can be utilized as well. Make sure that the user under which the build agent machine runs is a Windows AD user imported in Orchestrator and has the rights of adding nuget packages (Packages Create).
Strong recommendation: don’t hard code username and password fields, use variables!

Deploy function requires **NuGet** to be installed on the agent machine. The recommended version is 2.8 or newer.



UiPath Integration (Public Preview).md

Open with





